@@ -486,11 +486,19 @@ def new_project():
                 homepage=form.homepage.data.strip(),
                 backend=form.backend.data.strip(),
                 version_scheme=form.version_scheme.data.strip(),
-                version_url=form.version_url.data.strip() or None,
-                version_prefix=form.version_prefix.data.strip() or None,
-                pre_release_filter=form.pre_release_filter.data.strip() or None,
-                version_filter=form.version_filter.data.strip() or None,
-                regex=form.regex.data.strip() or None,
+                version_url=form.version_url.data.strip()
+                if form.version_url.data
+                else None,
+                version_prefix=form.version_prefix.data.strip()
+                if form.version_prefix.data
+                else None,
+                pre_release_filter=form.pre_release_filter.data.strip()
+                if form.pre_release_filter.data
+                else None,
+                version_filter=form.version_filter.data.strip()
+                if form.version_filter.data
+                else None,
+                regex=form.regex.data.strip() if form.regex.data else None,
                 user_id=flask.g.user.username,
                 releases_only=form.releases_only.data,
             )
@@ -570,13 +578,25 @@ def edit_project(project_id):
                 name=form.name.data.strip(),
                 homepage=form.homepage.data.strip(),
                 backend=form.backend.data.strip(),
-                version_scheme=form.version_scheme.data.strip(),
-                version_pattern=form.version_pattern.data.strip(),
-                version_url=form.version_url.data.strip(),
-                version_prefix=form.version_prefix.data.strip(),
-                pre_release_filter=form.pre_release_filter.data.strip(),
-                version_filter=form.version_filter.data.strip(),
-                regex=form.regex.data.strip(),
+                version_scheme=form.version_scheme.data.strip()
+                if form.version_scheme.data
+                else None,
+                version_pattern=form.version_pattern.data.strip()
+                if form.version_pattern.data
+                else None,
+                version_url=form.version_url.data.strip()
+                if form.version_url.data
+                else None,
+                version_prefix=form.version_prefix.data.strip()
+                if form.version_prefix.data
+                else None,
+                pre_release_filter=form.pre_release_filter.data.strip()
+                if form.pre_release_filter.data
+                else None,
+                version_filter=form.version_filter.data.strip()
+                if form.version_filter.data
+                else None,
+                regex=form.regex.data.strip() if form.regex.data else None,
                 insecure=form.insecure.data,
                 user_id=flask.g.user.username,
                 check_release=form.check_release.data,
@@ -733,7 +753,7 @@ def edit_project_mapping(project_id, pkg_id):
 
 
 def format_examples(examples):
-    """ Return the plugins examples as HTML links. """
+    """Return the plugins examples as HTML links."""
     output = ""
     if examples:
         for cnt, example in enumerate(examples):
@@ -745,7 +765,7 @@ def format_examples(examples):
 
 
 def context_class(category):
-    """ Return bootstrap context class for a given category. """
+    """Return bootstrap context class for a given category."""
     values = {"message": "default", "error": "danger", "info": "info"}
     return values.get(category, "warning")
 
